<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
		xmlns:xlink="http://www.w3.org/1999/xlink"
		version="1.0" > 
	<xsl:output method="html" version="4"/>

	<xsl:param name="base_ref" ></xsl:param>
	<xsl:param name="mode_view" select="3"/>
	<xsl:param name="mode_fill" select="true"/>
	<xsl:param name="commands">commands.svg</xsl:param>
	<xsl:template match="/">
		<html >
			<head>
				<title>Parts Catalog</title>
				<meta http-equiv="content-type" content="text/html; charset=ISO-8859-1"/>
				<meta name="author" content="Erick.FAUQUETTE@fr.thalesgroup.com"/>
				<link rel="stylesheet" href="{$base_ref}styles/s2000m.css"/>
				<script type="text/ecmascript"> 
					var zoom_range=<xsl:value-of select="part/@xml:zoom_range" />;
					var small_image='<xsl:value-of select="part/@xml:small" />';
				</script>
				<script language="JavaScript" src="scripts/svg_commands.js"></script>
			</head>

			<body onload="svg_init()" onresize="on_resize(event)" >
				<xsl:apply-templates/>
			</body>
		</html>
	</xsl:template>



	<xsl:template match="part[@xlink:type='extended']">
		<table  border="0" cellpadding="1" cellspacing="1"  align="center">
		<xsl:choose>
			<xsl:when test="$mode_view=1">	
				<tr><td colspan="2" align="center"><xsl:call-template name="illustration"/></td></tr>
				<tr><td><xsl:call-template name="commands"/></td>
				<td ><xsl:call-template name="data_table"/></td></tr>
			</xsl:when>
			<xsl:when test="$mode_view=2">	
				<tr><td align="center"><xsl:call-template name="illustration"/></td></tr>
				<tr><td align="center"><xsl:call-template name="commands"/></td></tr>
				<tr><td align="center"><xsl:call-template name="data_table"/></td></tr>
			</xsl:when>
			<xsl:otherwise>
				<tr><td rowspan="2" align="center"><xsl:call-template name="illustration"/></td>
				<td><xsl:call-template name="commands"/></td></tr>
				<tr><td ><xsl:call-template name="data_table"/></td></tr>		
			</xsl:otherwise>
		</xsl:choose>
		</table>		


	</xsl:template>

	<xsl:template match="part[@xlink:type='locator']">
		<tr>
			<xsl:attribute name="id"><xsl:value-of select="substring-after(@xlink:href, '#')"/></xsl:attribute> 
			<xsl:attribute name="onMouseOver">on_mouse_over('<xsl:value-of select="substring-after(@xlink:href, '#part-')"/>')</xsl:attribute> 
			<xsl:attribute name="onMouseOut">on_mouse_out('<xsl:value-of select="substring-after(@xlink:href, '#part-')"/>')</xsl:attribute>
			<xsl:attribute name="onclick">on_mouse_click('<xsl:value-of select="substring-after(@xlink:href, '#part-')"/>')</xsl:attribute>
			<xsl:attribute name="style">background-color:white;</xsl:attribute>
			<td align="center"><xsl:value-of select="substring-after(@xlink:href, '#part-')"/></td>
			<td align="center"><xsl:value-of select="./qty"/></td>
			<td nowrap="nowrap"><xsl:value-of select="./description"/></td>
		</tr>
	</xsl:template>


	<xsl:template name="illustration">
					<table border="0" cellpadding="0" cellspacing="0" >
						<tr>
							<td background="{$base_ref}images/border_up_left20.gif">&#160;</td>
							<td background="{$base_ref}images/border_up20.gif">&#160;</td>
							<td background="{$base_ref}images/border_up_right20.gif">&#160;</td>
						</tr>
						<tr>
							<td background="{$base_ref}images/border_left20.gif">&#160;</td>
							<td>
								<!-- The parts catalog illustration -->
								<div align="center">
									<embed id="figure" width="600" height="600" type="image/svg+xml" >
										<xsl:attribute name="src"><xsl:value-of select="@xml:base"/></xsl:attribute>
									</embed>
								</div></td>
							<td background="{$base_ref}images/border_right20.gif">&#160;</td>
						</tr>
						<tr>
							<td background="{$base_ref}images/border_bottom_left20.gif" width="10px" height="23px">&#160;</td>
							<td background="{$base_ref}images/border_bottom20.gif" width="10px" height="23px">&#160;</td>
							<td background="{$base_ref}images/border_bottom_right20.gif" width="10px" height="23px">&#160;</td>
						</tr>
					</table>
	</xsl:template>
	
	<xsl:template name="commands">
		<table border="0" cellpadding="0" cellspacing="0">
			<tr>
				<td background="{$base_ref}images/border_up_left20.gif">&#160;</td>
				<td background="{$base_ref}images/border_up20.gif">&#160;</td>
				<td background="{$base_ref}images/border_up_right20.gif">&#160;</td>
			</tr>
			<tr><xsl:attribute name="onClick">svg_viewbox()</xsl:attribute> 
				<td background="{$base_ref}images/border_left20.gif">&#160;</td>
				<td>
				<table border="0" cellpadding="0" cellspacing="0" align="center">
				<tr><td>
				
					<!--	<embed id="figure_small" width="130" height="130" type="image/svg+xml" src="{@xml:base}"/>
						<xsl:attribute name="src"><xsl:value-of select="@xml:base"/></xsl:attribute>
						</embed> -->
					<embed id="commands" width="290" height="110" type="image/svg+xml" src="{$commands}" />
				</td></tr>
				</table></td>
			<td background="{$base_ref}images/border_right20.gif">&#160;</td>
			</tr>
			<tr>
				<td background="{$base_ref}images/border_bottom_left20.gif" width="10px" height="23px">&#160;</td>
				<td background="{$base_ref}images/border_bottom20.gif" width="10px" height="23px">&#160;</td>
				<td background="{$base_ref}images/border_bottom_right20.gif" width="10px" height="23px">&#160;</td>
			</tr>
		</table>
	</xsl:template>
	
	<xsl:template name="data_table">
					<table border="0" cellpadding="0" cellspacing="0" >
						<tr>
							<td background="{$base_ref}images/border_up_left20.gif">&#160;</td>
							<td background="{$base_ref}images/border_up20.gif">&#160;</td>
							<td background="{$base_ref}images/border_up_right20.gif" >&#160;</td>
						</tr>
						<tr>
							<td background="{$base_ref}images/border_left20.gif">&#160;</td>
							<td>	

								<!-- The parts catalog description -->

								<table border="0" cellpadding="0" cellspacing="0">
									<tr>
										<th align="center" >Part Nbr.</th>
										<th align="center">Part Qty.</th>
										<th>Description</th>
									</tr>
								<xsl:apply-templates/>
								</table>
							</td>
							<td background="{$base_ref}images/border_right20.gif">&#160;</td>
						</tr>
						<tr>
							<td background="{$base_ref}images/border_bottom_left20.gif" width="10px" height="23px">&#160;</td>
							<td background="{$base_ref}images/border_bottom20.gif" width="10px" height="23px">&#160;</td>
							<td background="{$base_ref}images/border_bottom_right20.gif" width="10px" height="23px">&#160;</td>
						</tr>
					</table>

	</xsl:template>
</xsl:stylesheet>